.heart[data-v-7811382a]{width:280px;height:220px;display:flex;justify-content:space-between}.heart span[data-v-7811382a]{--c:plum;--h:50%;--t:25%;background-color:var(--c);width:20px;border-radius:10px;position:relative;height:var(--h);top:var(--t);-webkit-animation:beating-data-v-7811382a 1s infinite;animation:beating-data-v-7811382a 1s infinite}.heart span[data-v-7811382a]:first-child,.heart span[data-v-7811382a]:nth-child(9){--c:#f08080;--h:60px;--t:44px}.heart span[data-v-7811382a]:nth-child(2),.heart span[data-v-7811382a]:nth-child(8){--c:#87cefa;--h:120px;--t:12px}.heart span[data-v-7811382a]:nth-child(3),.heart span[data-v-7811382a]:nth-child(7){--c:#90ee90;--h:160px;--t:0}.heart span[data-v-7811382a]:nth-child(4),.heart span[data-v-7811382a]:nth-child(6){--c:gold;--h:180px;--t:16px}.heart span[data-v-7811382a]:nth-child(5){--c:plum;--h:188px;--t:32px}.current-warpper[data-v-7811382a]{display:flex;justify-content:center;align-items:center}.current-warpper span[data-v-7811382a]{color:rgba(0,0,0,.3);text-shadow:1px 1px 3px hsla(0,0%,100%,.7)}.author[data-v-7811382a]{position:fixed;bottom:0;left:0;right:0;margin-left:auto;margin-right:auto;margin-top:auto;display:flex;justify-content:center;align-items:flex-start}.author span[data-v-7811382a]{color:hsla(0,0%,100%,.8)}@-webkit-keyframes beating-data-v-7811382a{0%,30%{height:var(--h);top:var(--t);background-color:var(--c);filter:blur(0)}60%,70%{height:50%;top:25%;background-color:plum;filter:blur(5px)}}@keyframes beating-data-v-7811382a{0%,30%{height:var(--h);top:var(--t);background-color:var(--c);filter:blur(0)}60%,70%{height:50%;top:25%;background-color:plum;filter:blur(5px)}}body{margin:0;height:100vh;display:flex;align-items:center;justify-content:center;background:radial-gradient(circle at center,#9370db,#000)}